@@ -10,13 +10,15 @@ import time
 
 
 class ConfuseCallback(tf.keras.callbacks.Callback):
-    def __init__(self, x_test, y_test, file_writer, class_names=None, figure_size=(12, 10)):
+
+    def __init__(self, x_test, y_test, file_writer, class_names=None, figure_size=(12, 10), batch_size=32):
         super(ConfuseCallback, self).__init__()
         self.x_test = x_test
         self.y_test = y_test if len(y_test.shape) == 1 else np.argmax(y_test, axis=1)
         self.file_writer = file_writer
         self.figure_size = figure_size
         self.label_names = class_names
+        self.batch_size = batch_size
 
         if self.label_names is None:
             self.label_names = ["Class {:02d}".format(unique_label) for unique_label in np.unique(self.y_test)]
@@ -59,7 +61,11 @@ class ConfuseCallback(tf.keras.callbacks.Callback):
 
     def on_epoch_end(self, epoch, logs=None):
         try:
-            test_pred = self.model.predict(self.x_test)
+            test_pred = []
+            for b in range(0, self.x_test.shape[0], self.batch_size):
+                x_feed = self.x_test[b:b+self.batch_size]
+                pred = self.model.predict(x_feed)
+                test_pred = np.concatenate([test_pred, pred])
             test_pred = tf.argmax(test_pred, axis=1)
             accuracy = np.sum(test_pred == self.y_test) / self.y_test.shape[0]
 
@@ -141,7 +147,7 @@ def wait_ctrl_c(pre_msg="Press Ctrl+c to quit Tensorboard", post_msg="\nExit."):
 
 def get_tf_callbacks(root,
                      tboard_callback=True, tboard_update_freq='epoch', tboard_histogram_freq=1, tboard_profile_batch=0,
-                     confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, y_argmax=False, figure_size=(12, 10),
+                     confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, figure_size=(12, 10),
                      modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0,
                      earlystop_callback=True, earlystop_monitor='val_loss', earlystop_patience=0, earlystop_restore_weights=True):
     postfix = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
